@@ -1,44 +1,18 @@
 /*
  * Copyright 2005 - 2015  Zarafa B.V. and its licensors
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation with the following
- * additional terms according to sec. 7:
- * 
- * "Zarafa" is a registered trademark of Zarafa B.V.
- * The licensing of the Program under the AGPL does not imply a trademark 
- * license. Therefore any rights, title and interest in our trademarks 
- * remain entirely with us.
- * 
- * Our trademark policy (see TRADEMARKS.txt) allows you to use our trademarks
- * in connection with Propagation and certain other acts regarding the Program.
- * In any case, if you propagate an unmodified version of the Program you are
- * allowed to use the term "Zarafa" to indicate that you distribute the Program.
- * Furthermore you may use our trademarks where it is necessary to indicate the
- * intended purpose of a product or service provided you use it in accordance
- * with honest business practices. For questions please contact Zarafa at
- * trademark@zarafa.com.
+ * as published by the Free Software Foundation.
  *
- * The interactive user interface of the software displays an attribution 
- * notice containing the term "Zarafa" and/or the logo of Zarafa. 
- * Interactive user interfaces of unmodified and modified versions must 
- * display Appropriate Legal Notices according to sec. 5 of the GNU Affero 
- * General Public License, version 3, when you propagate unmodified or 
- * modified versions of the Program. In accordance with sec. 7 b) of the GNU 
- * Affero General Public License, version 3, these Appropriate Legal Notices 
- * must retain the logo of Zarafa or display the words "Initial Development 
- * by Zarafa" if the display of the logo is not reasonably feasible for
- * technical reasons.
- * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 /**
@@ -190,7 +164,7 @@ DHTML.prototype.addTextNode = function(parent, value)
 /**
  * Function will check if the elements has an firstChild.nodeValue
  * @param element: html element
- * @param value(optional): string that will be returned when firstChild.nodeValue not exists
+ * @param value(optional): string that will be returned when firstChild.nodeValue does not exist
  * @return string of firstChild.nodeValue
  */
 DHTML.prototype.getTextNode = function(element, value)
@@ -446,9 +420,8 @@ DHTML.prototype.removeEvents = function(element)
 				childElement.events = null;
 			}
 			
-			if(childElement.childNodes && childElement.childNodes.length > 0) {
+			if (childElement.childNodes && childElement.childNodes.length > 0)
 				dhtml.removeEvents(childElement);
-			}
 		}
 	}
 }
@@ -545,9 +518,8 @@ DHTML.prototype.deselectElement = function(id, className)
 {
 	var element = this.getElementById(id);
 
-	if(element && element.className.indexOf(className) > 0) {
+	if (element && element.className.indexOf(className) > 0)
 		element.className = element.className.substring(0, element.className.indexOf(className));
-	}
 }
 
 /**
@@ -1096,8 +1068,6 @@ DHTML.prototype.scrollFrame = function(iframe, id)
 		return;
 		
 	frame.contentWindow.document.body.scrollTop = el.offsetTop;
-	
-	return;
 }
 
 /**
